@@ -2,7 +2,7 @@ import subprocess
 import os, sys
 import inspect
 
-__version__ = '2.0'
+__version__ = '2.2'
 
 
 PACKAGE_NAME = None
@@ -16,9 +16,10 @@ class m1n1Exception(Exception):
 
 def set_package_name(name):
 	global locked
-	locked = True
-	global PACKAGE_NAME
-	PACKAGE_NAME = name
+	if not locked:
+		locked = True
+		global PACKAGE_NAME
+		PACKAGE_NAME = name
 
 def detachret(cond, err, dir):
 	if (PACKAGE_NAME is None) and (not locked):
@@ -42,4 +43,8 @@ def reterror(err):
 		sys.exit('Internal error: PACKAGE_NAME was not set!')
 	caller_frame = inspect.stack()[1]
 	caller = os.path.basename(caller_frame.filename)
-	raise m1n1Exception(err, caller)
\ No newline at end of file
+	raise m1n1Exception(err, caller)
+
+def unlock():
+	global locked
+	locked = False
\ No newline at end of file
